Installation
============

Please install a suitable python-distribution first. We recommend Anaconda-Python.

Afterwards you can install *pyrotoolbox* in the "Anaconda Command Prompt" by typing

.. code-block:: console

    pip install pyrotoolbox
